#
'''
Kuper export Tool for selected camera in Maya 
written Dinesh Bishnoi/Dan Lowenberg Aug 2014
Modified by Dinesh Soni March 2015

Change Log -
March 2015 - Script no longer writes the pts info to the Kuper file during null objects export files.

- need to select camera or object group

- create button with the following -

	import kuperExportfromMaya as ke
	reload(ke)
	ke.main()

'''


import maya.cmds as cmds
import maya.mel as mel

version = '1.8.1'
print 'version= %s\n' %version



global f
global filetoWrite
filetoWrite =''

# filetoWrite = '/mnt/users/daniel/mayacam.asc'

def defineSeletion():
    selectionList =[]
    cam=''
    pggroup=''
    vobjgroup=''
    sels =cmds.ls(sl=True)
    for each in sels:
        cams = cmds.listRelatives(each,s=True, c= True)
        if cams != None: #not transform
            if (cmds.objectType(cams[0]) =='camera'):
                camera = 'camera_%s' %each
                selectionList.append(camera)
                #print 'camera=%s' %camera    
        else:
            connections = cmds.listConnections(each,t='animCurve')
            if connections != None:
                objgroup = 'vobjgroup_%s' %each
                selectionList.append(objgroup)
                #print 'objgroup=%s' %pggroup    
            else:
                pggroup = 'pointgrp_%s' %each
                selectionList.append(pggroup)
                #print 'pggroup=%s' %pggroup
    selectionList.sort()
    #print selectionList
    return selectionList

def choosefile():
    multipleFilters = "ASCII (*.asc);;All Files (*.*)"
    filetoWrite = cmds.fileDialog2(fileFilter=multipleFilters, dialogStyle=2)

    if  filetoWrite != None:   
        print 'filetoWrite = %s' %filetoWrite[0]
        return filetoWrite[0]
    else:
        return

def openfile(whichfile):
    global f
    if (whichfile !=None):
        try:
            if f.closed == True:
                f = open(whichfile,'w')
            else:
                f = open(whichfile,'a')
        except:
            f = open(whichfile,'w')
        print '\nopened file to write'
        return True
    else:
        print '\nfailed to open file to write'
        return False

def closefile():
    global f
    try:
        f.close()
        print 'closed file\n'
    except:
        print ''

def writeCameraAnim(whichCam):
    global f
    frameStart = cmds.playbackOptions( q=True, minTime=True)
    frameEnd = cmds.playbackOptions( q=True, maxTime=True)

    # ---------------- Header -----------------------------------
    #f.write('group_camera = %s' %whichCam)
    f.write('Axes = frame, VTrack, VEW, VNS, Vpan, VTilt, VRoll, focal\n')

    # frames
    for frame in range(int(frameStart),int(frameEnd)+1):

        cmds.currentTime(frame, edit=True )
        translates=cmds.xform(whichCam, q=True,ws=True, t=True)
        Tx = translates[0]
        Ty = translates[1]
        Tz = translates[2]

        rotates=cmds.xform(whichCam, q=True,ws=True, ro=True)
        Rx=rotates[0]
        Ry=rotates[1] 
        Rz=rotates[2]
        focal = cmds.camera(whichCam,q=True,fl=True)
        # order is = Frame, Tz, Tx, Ty, -Ry, Rx, -Rz (with spaces)
        f.write('%.6f %.9f %.9f %.9f %.9f %.9f %.9f %.9f\n' %(frame, Tz, Tx, Ty, -Ry, Rx, -Rz, focal))


def writeObjectAnim(whichObj):
    global f
    frameStart = cmds.playbackOptions( q=True, minTime=True)
    frameEnd = cmds.playbackOptions( q=True, maxTime=True)

    # ---------------- Header -----------------------------------
    #f.write('\ngroup_object = %s' %whichObj)
    f.write('Axes = frame, VTrack, VEW, VNS, Vpan, VTilt, VRoll\n')

    # frames
    for frame in range(int(frameStart),int(frameEnd)+1):

        cmds.currentTime(frame, edit=True )
        translates=cmds.xform(whichObj, q=True,ws=True, t=True)
        Tx = translates[0]
        Ty = translates[1]
        Tz = translates[2]

        rotates=cmds.xform(whichObj, q=True,ws=True, ro=True)
        Rx=rotates[0]
        Ry=rotates[1] 
        Rz=rotates[2]
        # order is = Frame, Tz, Tx, Ty, -Ry, Rx, -Rz (with spaces)
        f.write('%.6f %.9f %.9f %.9f %.9f %.9f %.9f\n' %(frame, Tz, Tx, Ty, -Ry, Rx, -Rz))


def writePtsInfo(whichType,whichgrp):
    global f
    locatorList=[]
    # this is just the survey of the locators under the PGroup
    # ---------------- Header -----------------------------------
    f.write('\npoints_%s = %s\n' %(whichType,whichgrp))
    childList = cmds.listRelatives(whichgrp, type='transform',c=True)
    for eachSel in childList:
        shape = cmds.listRelatives(eachSel,s=True, c= True)[0]
        #print 'shape=%s' %shape
        if cmds.objectType(str(shape)) == 'locator':
            locatorList.append(str(eachSel))
    #print 'locatorList=%s' %locatorList

    for transform in locatorList:
        t=cmds.xform(transform, q=1,ws=1,t=1)
        tokens=transform.split("|")
        # Get the short name of the transform
        f.write((tokens[- 1] + " point x: " + str(t[0]) + " y: " + str(t[1]) + " z: " + str(t[2]) + "\n"))


def main():
    global filetoWrite
    selectionList = defineSeletion()
    if len(selectionList)>0:
        filetoWrite=choosefile()
    else:
        cmds.warning ('please select a camera, point group, and or object group')

    for each in selectionList:
        grouptype = str(each.split('_')[0])
        if grouptype == 'camera':
            camera =each.split('camera_')[1]
            if filetoWrite != '':
                if openfile(filetoWrite):
                    print '\ncamera=%s' %camera
                    writeCameraAnim(camera)
                    print 'camera Info written\n'
                    #closefile()

        if grouptype == 'vobjgroup':
            objgroup=each.split('vobjgroup_')[1]
            if filetoWrite != '':
                if openfile(filetoWrite):
                    print 'objgroup=%s' %objgroup
                    writeObjectAnim(objgroup)
                    print 'objgroup Info written\n'
                    #writePtsInfo('object', objgroup)
                    #closefile()

        if grouptype == 'pointgrp':
            pointgrp=each.split('pointgrp_')[1]
            if filetoWrite != '':
                if openfile(filetoWrite):
                    print 'pointgrp=%s' %pointgrp
                    #writePtsInfo('camera', pointgrp)
                    print 'pointgrp Info written\n'
                    #closefile()


    if filetoWrite != '':
        filetoWrite = ''
        closefile()





'''

#### -----------------------------------------------------------------------


def ExportLogClipboard():

        
    fileId.write("# " + os.environ[ "USER" ] + "@" + os.environ[ "HOST" ] + "\n")
    fileId.write("# " + internal.shellOutput("date", convertNewlines=False, stripTrailingNewline=False))
    fileId.write("# Coordinates are in world space\n")

    selection=ls(type="transform",l=1,sl=1)
    for transform in selection:
        t=xform(transform, q=1,ws=1,t=1)
        tokens=transform.split("|")
        # Get the short name of the transform
        fileId.write((tokens[- 1] + " point x: " + str(t[0]) + " y: " + str(t[1]) + " z: " + str(t[2]) + "\n"))
        
    fileId.close()
    print "Done.\n"
    print "------------------------------\n"
    return 1
    
'''


'''

from pymel.all import *
melGlobals.initVar( 'string', 'gMainPane' )
# ----------------- Hide Model Panel with Cam for Baking --------------------------------------
def toggleModelPanel(state):
    melGlobals.initVar( 'string', 'gMainPane' )
    # Set View Interface for Baking
    i=0
    currentCameras=[]
    currentModelPanels=[]
    currentClipingPlane=int(getAttr('persp.farClipPlane'))
    currentPanels=[str(paneLayout(melGlobals['gMainPane'],
        query=1,pane1=1)),str(paneLayout(melGlobals['gMainPane'],
        query=1,pane2=1)),str(paneLayout(melGlobals['gMainPane'],
        pane3=1,query=1)),str(paneLayout(melGlobals['gMainPane'],
        query=1,pane4=1))]
    for cur in currentPanels:
        type=str(getPanel(typeOf=cur))
        if type == "modelPanel":
            currentModelPanels[i]=str(cur)
            currentCameras[i]=str(modelPanel(currentModelPanels[i],
                q=1,camera=1))
            mel.lookThroughModelPanel('persp', currentModelPanels[i])
            i+=1
            
        
    if state == 1:
        setAttr('persp.farClipPlane',0.001)
        select()
        for cur in currentModelPanels:
            isolateSelect(cur,
                state=1)
            
        currentViewPref=str(playbackOptions(q=1,v=1))
        playbackOptions(v="active")
        print "\n hiding panels"
        
    
    else:
        setAttr('persp.farClipPlane',100000)
        select()
        for cur in currentModelPanels:
            isolateSelect(cur,
                state=0)
            
        print "\n showing panels"
        #string $currentViewPref = `playbackOptions -q -v`; playbackOptions -v "active";
        
    
# ------------- Detect Animated Object ----------------------

string $connections[] = `listConnections -t animCurve $endCam`;
float $Keyframes[] = `keyframe -index 0  -query $connections[0]`;
float $firstKey= $Keyframes[0];

'''
